@@ -32,12 +32,6 @@ class URLMarble(DispatchMarble):
         persistent_state=None, 
         flow_state=None
     ):
-        if not hasattr(marble, 'urls'):
-            raise Exception(
-                '%r marble has no \'urls\' attribute specified'%(
-                    marble.__class__.__name__,
-                )
-            )
         DispatchMarble.__init__(
             marble, 
             bag,
@@ -48,7 +42,14 @@ class URLMarble(DispatchMarble):
             persistent_state,
             flow_state,
         )
-        marble.ruleset = RuleSet(marble.urls)
+        if not hasattr(marble, 'urls'):
+            raise Exception(
+                '%r marble has no \'urls\' attribute specified'%(
+                    marble.__class__.__name__,
+                )
+            )
+        else:
+            marble.ruleset = RuleSet(marble.urls)
         marble.log = persistent_state['log']
         #marble.path = persistent_state['path']
         marble._area_cache = persistent_state['_area_cache']
@@ -69,12 +70,13 @@ class URLMarble(DispatchMarble):
             return conversion.result.url
 
     def redirect(marble, **p):
-        conversion = marble.url(**p)
+        url = marble.url(**p)
+        # @@@ Could put a check in here for redirecting back to current URL.
         marble.bag.http_response.status = '301 Redirect' 
         marble.bag.http_response.header_list.append(
             dict(
                 name='Location', 
-                value=str(conversion.result.url)
+                value=url.encode('utf8')
             )
         )
         marble.bag.http_response.body = ['Redirecting...']
